@@ -1,4 +1,4 @@
 package t::lib::C;
-use c3;
+use Class::C3;
 use base ('t::lib::A', 't::lib::B');
-1;
\ No newline at end of file
+1;
