@@ -1,4 +1,4 @@
 package t::lib::F;
-use c3;
+use Class::C3;
 use base ('t::lib::C', 't::lib::D');
-1;
\ No newline at end of file
+1;
